<?php

namespace App\Admin\Controllers;

use App\Admin\Repositories\Episode;
use App\Models\EpisodesCategory;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Show;
use Dcat\Admin\Http\Controllers\AdminController;

class EpisodeController extends AdminController
{
    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        return Grid::make(new Episode(), function (Grid $grid) {
            $grid->column('id')->sortable();
            $grid->column('name');
            $grid->column('cover_img')->image();
            $grid->column('status');
            $grid->column('is_opend');
            $grid->column('sort');
            $grid->column('is_vip_watch');
            $grid->column('free_episodes');
            $grid->column('paid_episodes');
            $grid->column('episodes_price');
            $grid->column('created_at');

            $grid->filter(function (Grid\Filter $filter) {
                $filter->equal('id');

            });
        });
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     *
     * @return Show
     */
    protected function detail($id)
    {
        return Show::make($id, new Episode(), function (Show $show) {
            $show->field('id');
            $show->field('name');
            $show->field('cover_img');
            $show->field('status');
            $show->field('is_opend');
            $show->field('sort');
            $show->field('is_vip_watch');
            $show->field('free_episodes');
            $show->field('paid_episodes');
            $show->field('episodes_price');
            $show->field('created_at');
            $show->field('updated_at');
        });
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        return Form::make(new Episode(), function (Form $form) {
            $form->display('id');
            $form->text('name')->required();
            $categoryModel = app(\App\Models\EpisodesCategory::class);
            $cates = $categoryModel::select(['id','name'])->get()->toArray();
            $form->select('category_id')->options(array_column($cates,'name','id'))->required();
            $form->image('cover_img')->uniqueName()->autoUpload()->required();
            $form->switch('status')->default(0);
            $form->switch('is_opend')->default(0);
            $form->text('sort');
            $form->switch('is_vip_watch')->default(0);
            $form->text('free_episodes')->required();
            $form->text('paid_episodes')->required();
            $form->text('episodes_price')->required();

            $form->display('created_at');
            $form->display('updated_at');
        });
    }
}
