<?php

namespace App\Admin\Controllers;

use App\Admin\Repositories\User;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Show;
use Dcat\Admin\Http\Controllers\AdminController;

class UserController extends AdminController
{
    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        return Grid::make(new User(), function (Grid $grid) {
            $grid->column('id')->sortable();
            $grid->column('nickname','昵称');
            $grid->column('avatar','头像')->image('',50,50);
            $grid->column('is_vip','是否会员')->display(function (){
                return $this->info->is_vip?'是':'否';
            });
            $grid->column('mobile','手机号');
            $grid->column('integral','金币余额');
            $grid->column('created_at','注册时间');

            $grid->filter(function (Grid\Filter $filter) {
                $filter->equal('id','ID');
                $filter->equal('nickname','昵称');
                $filter->equal('mobile','手机号');
                $filter->equal('is_vip','是否会员')->select(function (){
                    return ['否','是'];
                });

            });

            $grid->disableCreateButton();
        });
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     *
     * @return Show
     */
    protected function detail($id)
    {
        return Show::make($id, new User(), function (Show $show) {
            $show->field('id');
            $show->field('nickname');
            $show->field('avatar');
            $show->field('password');
            $show->field('email');
            $show->field('mobile');
            $show->field('open_id');
            $show->field('union_id');
            $show->field('status');
            $show->field('email_verified_at');
            $show->field('remember_token');
            $show->field('created_at');
            $show->field('updated_at');
        });
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        return Form::make(new User(), function (Form $form) {
            $form->display('id');
            $form->text('nickname');
            $form->text('avatar');
            $form->text('password');
            $form->text('email');
            $form->text('mobile');
            $form->text('open_id');
            $form->text('union_id');
            $form->text('status');
            $form->text('email_verified_at');
            $form->text('remember_token');

            $form->display('created_at');
            $form->display('updated_at');
        });
    }
}
